@@ -1,5 +1,5 @@
 #!/bin/bash
-# $Id: 62113dca1ad438c607ca5f75b493087d41d4ede3 $
+# $Id: 17f9eafb1a9c972cd72606f02d712d95b6541ca3 $
 
 # Fills variable KERNEL_CONFIG
 determine_kernel_config_file() {
@@ -167,7 +167,7 @@ set_initramfs_compression_method() {
 		local cfg_DECOMPRESS_SUPPORT=$(kconfig_get_opt "${kernel_config}" "CONFIG_RD_${COMPRESS_INITRD_TYPE}")
 		if [[ "${cfg_DECOMPRESS_SUPPORT}" != "y" ]]
 		then
-			gen_die "The kernel config '${kernel_config}' this initramfs will be build for cannot decompress set --compress-initrd-type '${COMPRESS_INITRD_TYPE}'!"
+			gen_die "The kernel config '${kernel_config}' this initramfs will be built for cannot decompress set --compress-initrd-type '${COMPRESS_INITRD_TYPE}'!"
 		fi
 
 		# If we are not building kernel, there is no point in
@@ -347,13 +347,6 @@ config_kernel() {
 		unset kconfig_md5sum_old kconfig_md5sum_new
 	fi
 
-	# Check for suitable kmod
-	determine_KEXT
-	if ! isTrue "$(is_kext_supported_by_kmod "${KEXT}")"
-	then
-		gen_die "${KMOD_CMD} does not support chosen module compression algorithm. Please re-emerge sys-apps/kmod with USE=$(get_kext_kmod_use_flag "${KEXT}") enabled or adjust CONFIG_MODULE_COMPRESS_* kernel option!"
-	fi
-
 	local -a required_kernel_options
 	[ -f "${KCONFIG_MODIFIED_MARKER}" ] && rm "${KCONFIG_MODIFIED_MARKER}"
 
@@ -998,11 +991,13 @@ config_kernel() {
 			[ ${KV_NUMERIC} -le 4003 ] && kconfigs_microcode+=( 'CONFIG_MICROCODE_EARLY' )
 
 			# Intel
-			kconfigs_microcode_intel+=( 'CONFIG_MICROCODE_INTEL' )
+			[ ${KV_NUMERIC} -ge 6006 ] && kconfigs_microcode_intel+=( 'CONFIG_CPU_SUP_INTEL' )
+			[ ${KV_NUMERIC} -lt 6006 ] && kconfigs_microcode_intel+=( 'CONFIG_MICROCODE_INTEL' )
 			[ ${KV_NUMERIC} -le 4003 ] && kconfigs_microcode_intel+=( 'CONFIG_MICROCODE_INTEL_EARLY' )
 
 			# AMD
-			kconfigs_microcode_amd=( 'CONFIG_MICROCODE_AMD' )
+			[ ${KV_NUMERIC} -ge 6006 ] && kconfigs_microcode_amd+=( 'CONFIG_CPU_SUP_AMD' )
+			[ ${KV_NUMERIC} -lt 6006 ] && kconfigs_microcode_amd+=( 'CONFIG_MICROCODE_AMD' )
 			[ ${KV_NUMERIC} -le 4003 ] && kconfigs_microcode_amd+=( 'CONFIG_MICROCODE_AMD_EARLY' )
 
 			[[ "${MICROCODE}" == all ]]   && kconfigs_microcode+=( ${kconfigs_microcode_amd[@]} ${kconfigs_microcode_intel[@]} )
@@ -1023,14 +1018,16 @@ config_kernel() {
 			required_kernel_options+=( 'CONFIG_MICROCODE' )
 			case "${MICROCODE}" in
 				amd)
-					required_kernel_options+=( 'CONFIG_MICROCODE_AMD' )
+					[ ${KV_NUMERIC} -ge 6006 ] && required_kernel_options+=( 'CONFIG_CPU_SUP_AMD' )
+					[ ${KV_NUMERIC} -lt 6006 ] && required_kernel_options+=( 'CONFIG_MICROCODE_AMD' )
 					;;
 				intel)
-					required_kernel_options+=( 'CONFIG_MICROCODE_INTEL' )
+					[ ${KV_NUMERIC} -ge 6006 ] && required_kernel_options+=( 'CONFIG_CPU_SUP_INTEL' )
+					[ ${KV_NUMERIC} -lt 6006 ] && required_kernel_options+=( 'CONFIG_MICROCODE_INTEL' )
 					;;
 				all)
-					required_kernel_options+=( 'CONFIG_MICROCODE_AMD' )
-					required_kernel_options+=( 'CONFIG_MICROCODE_INTEL' )
+					[ ${KV_NUMERIC} -ge 6006 ] && required_kernel_options+=( 'CONFIG_CPU_SUP_AMD' 'CONFIG_CPU_SUP_INTEL' )
+					[ ${KV_NUMERIC} -lt 6006 ] && required_kernel_options+=( 'CONFIG_MICROCODE_AMD' 'CONFIG_MICROCODE_INTEL' )
 					;;
 			esac
 		else
