@@ -197,7 +197,7 @@ _gkbuild_main() {
 		then
 			found_dyn_files=$(scanelf -E ET_DYN "${executable_files_to_scan[@]}" 2>/dev/null)
 		fi
-	
+
 		if [[ -n "${found_dyn_files}" ]]
 		then
 			print_error 1 "Found the following dynamically linked programs:"
@@ -632,6 +632,10 @@ gkautomake() {
 # Wrapper for autoreconf.
 # Will die when command will exit with nonzero exit status.
 gkautoreconf() {
+	# >autoconf-2.69 will call gtkdocize when used in macros
+	# when called with --install parameter.
+	local -x GTKDOCIZE=true
+
 	gkexec "autoreconf --force --install ${*}"
 }
 
